@@ -525,11 +525,13 @@ class Components:
                     go.Bar(hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            marker_color=line_color, marker_line_color=line_color, name=element),
                 ])
+            fig.update_layout(width=683)
         else:
             fig = go.Figure(data=[
                 go.Scatter(mode='lines', hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            line=dict(color=line_color, width=1.5), name=element), ] )
-        fig.update_layout(plot_bgcolor='#1f2c56', paper_bgcolor='#1f2c56', height=60, width=700,
+            fig.update_layout(width=670)
+        fig.update_layout(plot_bgcolor='#1f2c56', paper_bgcolor='#1f2c56', height=60,
                           margin=dict(l=85, r=50, t=5, b=20),
                           font={"color": "white",'size': 9}, yaxis={'fixedrange': True}, xaxis={'fixedrange': True},
                           bargap=0, )
